# [LineFit: A Geometric Approach for Fitting Segments in Images]

## Inputs

Two inputs data are required: 
- an image (PNG, JPEG, TIF), with 1, 3 or 4 channels (RGB or grayscale).
- a gradient map (PNG, JPEG, TIF). The gradient map can be in float or int as long as the threshold parameter rho is adapted to the type of value. Gradient map can be obtained through classic methods (Sobel) but deep learning methods are recommended for better results. For freeform images, deep learning edge detection methods are recommended such as DexiNed [1] or SAM (Zero-shot edge dection mode) [2]. For more regular scene, using gradient maps returned by DeepLSD [3] is recommended. For both gradient maps, better results are obtained by filtering with a high threshold and then applying a dilation, before giving the gradient map to LineFit. 

## Parameters


- The parameter `--sigma` is the minimal number of inliers in a line, default: `10`.

- The parameter `--epsilon` is the fitting tolerance that specifies the maximal distance of an inlier from its line, default: `5`.

- The parameter `--rho` is the threshold over gradient magnitude, must be adapted to the gradient magnitude inputted, default: `0.15`.

- The parameter `--reg_mode` defines the regularization operator used. Three modes are possible (default: `0`): 
  - 0: Not regularities are used, recommended for freeform images,
  - 1: Parallel/orthogonal regularities, recommended for orthographic projection images,
  - 2: Concurrency to vanishing points regularities, recommended for indoor or outdoor images.

- The parameter `--init` defines the initialization. Use `LSD` for initializing lines with LSD lines, use `dense` for initializing lines through region growing over the 2D point cloud, default: `LSD`.

 

## Usage

- Some exemples:
```
LineFit.exe --input ..\data\sample1\0100.png --input-gradient ..\data\sample1\0100.tif --output-directory ..\output --sigma 7 --epsilon 5 --reg_mode 1
LineFit.exe --input ..\data\sample2\P1020171.jpg --input-gradient ..\data\sample2\P1020171.tif --output-directory ..\output --sigma 5 --epsilon 3 --reg_mode 2 
LineFit.exe --input ..\data\sample3\257098.jpg --input-gradient ..\data\sample3\257098.tif --output-directory ..\output --sigma 10 --epsilon 5 --reg_mode 0 --init dense
```

## References
[1] Soria, X., Sappa, A., Humanante, P., Akbarinia, A.: Dense extreme inception network for edge detection. Pattern Recognition (2023)
[2] Kirillov, A., Mintun, E., Ravi, N., Mao, H., Rolland, C., Gustafson, L., Xiao, T., Whitehead, S., Berg, A.C., Lo, W.Y., Dollár, P., Girshick, R.: Segment anything. In: ICCV (2023)
[3] Pautrat, R., Barath, D., Larsson, V., Oswald, M.R., Pollefeys, M.: Deeplsd: Line segment detection and refinement with deep image gradients. In: CVPR (2023)

